---
name: Bug report
about: Report an issue
title: ''
labels: bug
assignees: ''

---

**Description**

(A clear and concise description of the bug)

**Details**

- Version: [e.g. 0.25.1]
- Module: [e.g. units, datalib.ecmwf]
- OS: [e.g. ubuntu, windows]
- Reporter:

**Steps to Reproduce**

1. ...
2. ...

**Additional Notes**

(Additional code snippets, screenshots, potential solutions, etc)

